@@ -1,6 +1,6 @@
 package Pithub;
 BEGIN {
-  $Pithub::VERSION = '0.01003';
+  $Pithub::VERSION = '0.01004';
 }
 
 # ABSTRACT: Github v3 API
@@ -32,15 +32,15 @@ Pithub - Github v3 API
 
 =head1 VERSION
 
-version 0.01003
+version 0.01004
 
 =head1 SYNOPSIS
 
     use Pithub;
     use Data::Dumper;
 
-    $p = Pithub->new;
-    $result = $p->repos->get( user => 'plu', repo => 'Pithub' );
+    my $p = Pithub->new;
+    my $result = $p->repos->get( user => 'plu', repo => 'Pithub' );
 
     # $result->content is either an arrayref or an hashref
     # depending on the API call that has been made
@@ -48,11 +48,19 @@ version 0.01003
     printf "%s\n", $result->content->{clone_url};    # prints https://github.com/plu/Pithub.git
 
     # if the result is an arrayref, you can use the result iterator
-    $result = $p->repos->list( user => 'plu' );
+    my $result = $p->repos->list( user => 'plu' );
     while ( my $row = $result->next ) {
         printf "%s\n", $row->{name};
     }
 
+=head1 DOCUMENTATION
+
+Quite a lot of the L<Pithub> documentation has been taken directly
+from the great API documentation at
+L<Github|http://developer.github.com/v3/>. Please also read the
+documentation there, since it might be more complete and more
+up-to-date.
+
 =head1 WARNING
 
 L<Pithub> as well as the
@@ -64,12 +72,34 @@ L<Github v3 API|http://developer.github.com/v3/>.
 
 =head1 MODULES
 
-There are different ways of using Pithub library. You can either
-use the main module C<< Pithub >> to get access to all other
-modules like L<Pithub::Repos> for example, or you can use
-L<Pithub::Repos> directly. In the synopsis above, all the calls
-are equivalent. Here's an overview over all modules and how to
-get access to them:
+There are different ways of using the Pithub library. You can either
+use the main module L<Pithub> to get access to all other
+modules, like L<Pithub::Repos> for example. Or you can use
+L<Pithub::Repos> directly and create an instance of it. All
+modules accept the same L<attributes|Pithub::Base/ATTRIBUTES>,
+either in the constructor or later by calling the setters.
+
+Besides that there are other modules involved. Every method call
+which maps directly to a Github API call returns a
+L<Pithub::Result> object. This contains everything interesting
+about the response returned from the API call.
+
+L<Pithub::Base> might be interesting for two reasons:
+
+=over
+
+=item *
+
+The list of L<attributes|Pithub::Base/ATTRIBUTES> which all modules
+accept.
+
+=item *
+
+The L<request|Pithub::Base/request> method: In case Github adds a
+new API call which is not supported yet by L<Pithub> the
+L<request|Pithub::Base/request> method can be used directly to
+perform this new API call, there's some documentation on how to
+use it.
 
 =over
 
@@ -79,8 +109,8 @@ L<Pithub::Gists>
 
 See also: L<http://developer.github.com/v3/gists/>
 
-    $gists = Pithub->new->gists;
-    $gists = Pithub::Gists->new;
+    my $gists = Pithub->new->gists;
+    my $gists = Pithub::Gists->new;
 
 =over
 
@@ -90,9 +120,9 @@ L<Pithub::Gists::Comments>
 
 See also: L<http://developer.github.com/v3/gists/comments/>
 
-    $comments = Pithub->new->gists->comments;
-    $comments = Pithub::Gists->new->comments;
-    $comments = Pithub::Gists::Comments->new;
+    my $comments = Pithub->new->gists->comments;
+    my $comments = Pithub::Gists->new->comments;
+    my $comments = Pithub::Gists::Comments->new;
 
 =back
 
@@ -106,8 +136,8 @@ L<Pithub::GitData>
 
 See also: L<http://developer.github.com/v3/git/>
 
-    $git_data = Pithub->new->git_data;
-    $git_data = Pithub::GitData->new;
+    my $git_data = Pithub->new->git_data;
+    my $git_data = Pithub::GitData->new;
 
 =over
 
@@ -117,9 +147,9 @@ L<Pithub::GitData::Blobs>
 
 See also: L<http://developer.github.com/v3/git/blobs/>
 
-    $blobs = Pithub->new->git_data->blobs;
-    $blobs = Pithub::GitData->new->blobs;
-    $blobs = Pithub::GitData::Blobs->new;
+    my $blobs = Pithub->new->git_data->blobs;
+    my $blobs = Pithub::GitData->new->blobs;
+    my $blobs = Pithub::GitData::Blobs->new;
 
 =item *
 
@@ -127,9 +157,9 @@ L<Pithub::GitData::Commits>
 
 See also: L<http://developer.github.com/v3/git/commits/>
 
-    $commits = Pithub->new->git_data->commits;
-    $commits = Pithub::GitData->new->commits;
-    $commits = Pithub::GitData::Commits->new;
+    my $commits = Pithub->new->git_data->commits;
+    my $commits = Pithub::GitData->new->commits;
+    my $commits = Pithub::GitData::Commits->new;
 
 =item *
 
@@ -137,9 +167,9 @@ L<Pithub::GitData::References>
 
 See also: L<http://developer.github.com/v3/git/refs/>
 
-    $references = Pithub->new->git_data->references;
-    $references = Pithub::GitData->new->references;
-    $references = Pithub::GitData::References->new;
+    my $references = Pithub->new->git_data->references;
+    my $references = Pithub::GitData->new->references;
+    my $references = Pithub::GitData::References->new;
 
 =item *
 
@@ -147,9 +177,9 @@ L<Pithub::GitData::Tags>
 
 See also: L<http://developer.github.com/v3/git/tags/>
 
-    $tags = Pithub->new->git_data->tags;
-    $tags = Pithub::GitData->new->tags;
-    $tags = Pithub::GitData::Tags->new;
+    my $tags = Pithub->new->git_data->tags;
+    my $tags = Pithub::GitData->new->tags;
+    my $tags = Pithub::GitData::Tags->new;
 
 =item *
 
@@ -157,9 +187,9 @@ L<Pithub::GitData::Trees>
 
 See also: L<http://developer.github.com/v3/git/trees/>
 
-    $trees = Pithub->new->git_data->trees;
-    $trees = Pithub::GitData->new->trees;
-    $trees = Pithub::GitData::Trees->new;
+    my $trees = Pithub->new->git_data->trees;
+    my $trees = Pithub::GitData->new->trees;
+    my $trees = Pithub::GitData::Trees->new;
 
 =back
 
@@ -173,8 +203,8 @@ L<Pithub::Issues>
 
 See also: L<http://developer.github.com/v3/issues/>
 
-    $issues = Pithub->new->issues;
-    $issues = Pithub::Issues->new;
+    my $issues = Pithub->new->issues;
+    my $issues = Pithub::Issues->new;
 
 =over
 
@@ -184,9 +214,9 @@ L<Pithub::Issues::Comments>
 
 See also: L<http://developer.github.com/v3/issues/comments/>
 
-    $comments = Pithub->new->issues->comments;
-    $comments = Pithub::Issues->new->comments;
-    $comments = Pithub::Issues::Comments->new;
+    my $comments = Pithub->new->issues->comments;
+    my $comments = Pithub::Issues->new->comments;
+    my $comments = Pithub::Issues::Comments->new;
 
 =item *
 
@@ -194,9 +224,9 @@ L<Pithub::Issues::Events>
 
 See also: L<http://developer.github.com/v3/issues/events/>
 
-    $events = Pithub->new->issues->events;
-    $events = Pithub::Issues->new->events;
-    $events = Pithub::Issues::Events->new;
+    my $events = Pithub->new->issues->events;
+    my $events = Pithub::Issues->new->events;
+    my $events = Pithub::Issues::Events->new;
 
 =item *
 
@@ -204,9 +234,9 @@ L<Pithub::Issues::Labels>
 
 See also: L<http://developer.github.com/v3/issues/labels/>
 
-    $labels = Pithub->new->issues->labels;
-    $labels = Pithub::Issues->new->labels;
-    $labels = Pithub::Issues::Labels->new;
+    my $labels = Pithub->new->issues->labels;
+    my $labels = Pithub::Issues->new->labels;
+    my $labels = Pithub::Issues::Labels->new;
 
 =item *
 
@@ -214,9 +244,9 @@ L<Pithub::Issues::Milestones>
 
 See also: L<http://developer.github.com/v3/issues/milestones/>
 
-    $milestones = Pithub->new->issues->milestones;
-    $milestones = Pithub::Issues->new->milestones;
-    $milestones = Pithub::Issues::Milestones->new;
+    my $milestones = Pithub->new->issues->milestones;
+    my $milestones = Pithub::Issues->new->milestones;
+    my $milestones = Pithub::Issues::Milestones->new;
 
 =back
 
@@ -230,8 +260,8 @@ L<Pithub::Orgs>
 
 See also: L<http://developer.github.com/v3/orgs/>
 
-    $orgs = Pithub->new->orgs;
-    $orgs = Pithub::Orgs->new;
+    my $orgs = Pithub->new->orgs;
+    my $orgs = Pithub::Orgs->new;
 
 =over
 
@@ -241,9 +271,9 @@ L<Pithub::Orgs::Members>
 
 See also: L<http://developer.github.com/v3/orgs/members/>
 
-    $members = Pithub->new->orgs->members;
-    $members = Pithub::Orgs->new->members;
-    $members = Pithub::Orgs::Members->new;
+    my $members = Pithub->new->orgs->members;
+    my $members = Pithub::Orgs->new->members;
+    my $members = Pithub::Orgs::Members->new;
 
 =item *
 
@@ -251,9 +281,9 @@ L<Pithub::Orgs::Teams>
 
 See also: L<http://developer.github.com/v3/orgs/teams/>
 
-    $teams = Pithub->new->orgs->teams;
-    $teams = Pithub::Orgs->new->teams;
-    $teams = Pithub::Orgs::Teams->new;
+    my $teams = Pithub->new->orgs->teams;
+    my $teams = Pithub::Orgs->new->teams;
+    my $teams = Pithub::Orgs::Teams->new;
 
 =back
 
@@ -267,8 +297,8 @@ L<Pithub::PullRequests>
 
 See also: L<http://developer.github.com/v3/pulls/>
 
-    $pull_requests = Pithub->new->pull_requests;
-    $pull_requests = Pithub::PullRequests->new;
+    my $pull_requests = Pithub->new->pull_requests;
+    my $pull_requests = Pithub::PullRequests->new;
 
 =over
 
@@ -278,9 +308,9 @@ L<Pithub::PullRequests::Comments>
 
 See also: L<http://developer.github.com/v3/pulls/comments/>
 
-    $comments = Pithub->new->pull_requests->comments;
-    $comments = Pithub::PullRequests->new->comments;
-    $comments = Pithub::PullRequests::Comments->new;
+    my $comments = Pithub->new->pull_requests->comments;
+    my $comments = Pithub::PullRequests->new->comments;
+    my $comments = Pithub::PullRequests::Comments->new;
 
 =back
 
@@ -294,8 +324,8 @@ L<Pithub::Repos>
 
 See also: L<http://developer.github.com/v3/repos/>
 
-    $repos = Pithub->new->repos;
-    $repos = Pithub::Repos->new;
+    my $repos = Pithub->new->repos;
+    my $repos = Pithub::Repos->new;
 
 =over
 
@@ -305,9 +335,9 @@ L<Pithub::Repos::Collaborators>
 
 See also: L<http://developer.github.com/v3/repos/collaborators/>
 
-    $collaborators = Pithub->new->repos->collaborators;
-    $collaborators = Pithub::Repos->new->collaborators;
-    $collaborators = Pithub::Repos::Collaborators->new;
+    my $collaborators = Pithub->new->repos->collaborators;
+    my $collaborators = Pithub::Repos->new->collaborators;
+    my $collaborators = Pithub::Repos::Collaborators->new;
 
 =item *
 
@@ -315,9 +345,9 @@ L<Pithub::Repos::Commits>
 
 See also: L<http://developer.github.com/v3/repos/commits/>
 
-    $commits = Pithub->new->repos->commits;
-    $commits = Pithub::Repos->new->commits;
-    $commits = Pithub::Repos::Commits->new;
+    my $commits = Pithub->new->repos->commits;
+    my $commits = Pithub::Repos->new->commits;
+    my $commits = Pithub::Repos::Commits->new;
 
 =item *
 
@@ -325,9 +355,9 @@ L<Pithub::Repos::Downloads>
 
 See also: L<http://developer.github.com/v3/repos/downloads/>
 
-    $downloads = Pithub->new->repos->downloads;
-    $downloads = Pithub::Repos->new->downloads;
-    $downloads = Pithub::Repos::Downloads->new;
+    my $downloads = Pithub->new->repos->downloads;
+    my $downloads = Pithub::Repos->new->downloads;
+    my $downloads = Pithub::Repos::Downloads->new;
 
 =item *
 
@@ -335,9 +365,9 @@ L<Pithub::Repos::Forks>
 
 See also: L<http://developer.github.com/v3/repos/forks/>
 
-    $forks = Pithub->new->repos->forks;
-    $forks = Pithub::Repos->new->forks;
-    $forks = Pithub::Repos::Forks->new;
+    my $forks = Pithub->new->repos->forks;
+    my $forks = Pithub::Repos->new->forks;
+    my $forks = Pithub::Repos::Forks->new;
 
 =item *
 
@@ -345,9 +375,9 @@ L<Pithub::Repos::Keys>
 
 See also: L<http://developer.github.com/v3/repos/keys/>
 
-    $keys = Pithub->new->repos->keys;
-    $keys = Pithub::Repos->new->keys;
-    $keys = Pithub::Repos::Keys->new;
+    my $keys = Pithub->new->repos->keys;
+    my $keys = Pithub::Repos->new->keys;
+    my $keys = Pithub::Repos::Keys->new;
 
 =item *
 
@@ -355,9 +385,9 @@ L<Pithub::Repos::Watching>
 
 See also: L<http://developer.github.com/v3/repos/watching/>
 
-    $watching = Pithub->new->repos->watching;
-    $watching = Pithub::Repos->new->watching;
-    $watching = Pithub::Repos::Watching->new;
+    my $watching = Pithub->new->repos->watching;
+    my $watching = Pithub::Repos->new->watching;
+    my $watching = Pithub::Repos::Watching->new;
 
 =back
 
@@ -371,8 +401,8 @@ L<Pithub::Users>
 
 See also: L<http://developer.github.com/v3/users/>
 
-    $users = Pithub->new->users;
-    $users = Pithub::Users->new;
+    my $users = Pithub->new->users;
+    my $users = Pithub::Users->new;
 
 =over
 
@@ -382,9 +412,9 @@ L<Pithub::Users::Emails>
 
 See also: L<http://developer.github.com/v3/users/emails/>
 
-    $emails = Pithub->new->users->emails;
-    $emails = Pithub::Users->new->emails;
-    $emails = Pithub::Users::Emails->new;
+    my $emails = Pithub->new->users->emails;
+    my $emails = Pithub::Users->new->emails;
+    my $emails = Pithub::Users::Emails->new;
 
 =item *
 
@@ -392,9 +422,9 @@ L<Pithub::Users::Followers>
 
 See also: L<http://developer.github.com/v3/users/followers/>
 
-    $followers = Pithub->new->users->followers;
-    $followers = Pithub::Users->new->followers;
-    $followers = Pithub::Users::Followers->new;
+    my $followers = Pithub->new->users->followers;
+    my $followers = Pithub::Users->new->followers;
+    my $followers = Pithub::Users::Followers->new;
 
 =item *
 
@@ -402,25 +432,14 @@ L<Pithub::Users::Keys>
 
 See also: L<http://developer.github.com/v3/users/keys/>
 
-    $keys = Pithub->new->users->keys;
-    $keys = Pithub::Users->new->keys;
-    $keys = Pithub::Users::Keys->new;
+    my $keys = Pithub->new->users->keys;
+    my $keys = Pithub::Users->new->keys;
+    my $keys = Pithub::Users::Keys->new;
 
 =back
 
 =back
 
-Besides that there are other modules involved. Every method call
-which maps directly to a Github API call returns a
-L<Pithub::Result> object. This contains everything interesting
-about the response (L<Pithub::Response>) returned from the API
-call as well as the request (L<Pithub::Request>). Even the
-L<Pithub::Base> module might be interesting because this one
-provides the L<Pithub::Base/request> method, which is used by
-all other modules. In case Github adds a new API call which is
-not supported yet by L<Pithub> the L<Pithub::Base/request>
-method can be used directly.
-
 =head1 AUTHOR
 
 Johannes Plunien <plu@cpan.org>
