@@ -1,6 +1,6 @@
 package Pithub::Orgs::Teams;
 BEGIN {
-  $Pithub::Orgs::Teams::VERSION = '0.01003';
+  $Pithub::Orgs::Teams::VERSION = '0.01004';
 }
 
 # ABSTRACT: Github v3 Org Teams API
@@ -15,7 +15,11 @@ sub add_member {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: user'    unless $args{user};
-    return $self->request( PUT => sprintf( '/teams/%s/members/%s', $args{team_id}, $args{user} ) );
+    return $self->request(
+        method => 'PUT',
+        path   => sprintf( '/teams/%s/members/%s', delete $args{team_id}, delete $args{user} ),
+        %args,
+    );
 }
 
 
@@ -23,7 +27,11 @@ sub add_repo {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: repo'    unless $args{repo};
-    return $self->request( PUT => sprintf( '/teams/%s/repos/%s', $args{team_id}, $args{repo} ) );
+    return $self->request(
+        method => 'PUT',
+        path   => sprintf( '/teams/%s/repos/%s', delete $args{team_id}, delete $args{repo} ),
+        %args,
+    );
 }
 
 
@@ -31,29 +39,45 @@ sub create {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: org' unless $args{org};
     croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    return $self->request( POST => sprintf( '/orgs/%s/teams', $args{org} ), $args{data} );
+    return $self->request(
+        method => 'POST',
+        path   => sprintf( '/orgs/%s/teams', delete $args{org} ),
+        %args,
+    );
 }
 
 
 sub delete {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
-    return $self->request( DELETE => sprintf( '/teams/%s', $args{team_id} ) );
+    return $self->request(
+        method => 'DELETE',
+        path   => sprintf( '/teams/%s', delete $args{team_id} ),
+        %args,
+    );
 }
 
 
 sub get {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
-    return $self->request( GET => sprintf( '/teams/%s', $args{team_id} ) );
+    return $self->request(
+        method => 'GET',
+        path   => sprintf( '/teams/%s', delete $args{team_id} ),
+        %args,
+    );
 }
 
 
-sub get_repo {
+sub has_repo {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: repo'    unless $args{repo};
-    return $self->request( GET => sprintf( '/teams/%s/repos/%s', $args{team_id}, $args{repo} ) );
+    return $self->request(
+        method => 'GET',
+        path   => sprintf( '/teams/%s/repos/%s', delete $args{team_id}, delete $args{repo} ),
+        %args,
+    );
 }
 
 
@@ -61,28 +85,44 @@ sub is_member {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: user'    unless $args{user};
-    return $self->request( GET => sprintf( '/teams/%s/members/%s', $args{team_id}, $args{user} ) );
+    return $self->request(
+        method => 'GET',
+        path   => sprintf( '/teams/%s/members/%s', delete $args{team_id}, delete $args{user} ),
+        %args,
+    );
 }
 
 
 sub list {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: org' unless $args{org};
-    return $self->request( GET => sprintf( '/orgs/%s/teams', $args{org} ) );
+    return $self->request(
+        method => 'GET',
+        path   => sprintf( '/orgs/%s/teams', delete $args{org} ),
+        %args,
+    );
 }
 
 
 sub list_members {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
-    return $self->request( GET => sprintf( '/teams/%s/members', $args{team_id} ) );
+    return $self->request(
+        method => 'GET',
+        path   => sprintf( '/teams/%s/members', delete $args{team_id} ),
+        %args,
+    );
 }
 
 
 sub list_repos {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
-    return $self->request( GET => sprintf( '/teams/%s/repos', $args{team_id} ) );
+    return $self->request(
+        method => 'GET',
+        path   => sprintf( '/teams/%s/repos', delete $args{team_id} ),
+        %args,
+    );
 }
 
 
@@ -90,7 +130,11 @@ sub remove_member {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: user'    unless $args{user};
-    return $self->request( DELETE => sprintf( '/teams/%s/members/%s', $args{team_id}, $args{user} ) );
+    return $self->request(
+        method => 'DELETE',
+        path   => sprintf( '/teams/%s/members/%s', delete $args{team_id}, delete $args{user} ),
+        %args,
+    );
 }
 
 
@@ -98,7 +142,11 @@ sub remove_repo {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: repo'    unless $args{repo};
-    return $self->request( DELETE => sprintf( '/teams/%s/repos/%s', $args{team_id}, $args{repo} ) );
+    return $self->request(
+        method => 'DELETE',
+        path   => sprintf( '/teams/%s/repos/%s', delete $args{team_id}, delete $args{repo} ),
+        %args,
+    );
 }
 
 
@@ -106,7 +154,11 @@ sub update {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
-    return $self->request( PATCH => sprintf( '/teams/%s', $args{team_id} ), $args{data} );
+    return $self->request(
+        method => 'PATCH',
+        path   => sprintf( '/teams/%s', delete $args{team_id} ),
+        %args,
+    );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -122,7 +174,7 @@ Pithub::Orgs::Teams - Github v3 Org Teams API
 
 =head1 VERSION
 
-version 0.01003
+version 0.01004
 
 =head1 METHODS
 
@@ -138,7 +190,8 @@ team is associated with.
 
 Examples:
 
-    $result = $p->orgs->teams->add_member(
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->add_member(
         team_id => 1,
         user    => 'plu',
     );
@@ -156,7 +209,8 @@ an owner of the org that the team is associated with.
 
 Examples:
 
-    $result = $p->orgs->teams->add_repo(
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->add_repo(
         team_id => 1,
         repo    => 'some_repo',
     );
@@ -174,7 +228,8 @@ owner of the given organization.
 
 Examples:
 
-    $result = $p->orgs->teams->create(
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->create(
         org  => 'CPAN-API',
         data => {
             name       => 'new team',
@@ -196,7 +251,8 @@ of the org that the team is associated with.
 
 Examples:
 
-    $result = $p->orgs->teams->delete( team_id => 1 );
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->delete( team_id => 1 );
 
 =back
 
@@ -210,11 +266,12 @@ Get team
 
 Examples:
 
-    $result = $p->orgs->teams->get( team_id => 1 );
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->get( team_id => 1 );
 
 =back
 
-=head2 get_repo
+=head2 has_repo
 
 =over
 
@@ -224,7 +281,8 @@ Get team repo
 
 Examples:
 
-    $result = $p->orgs->teams->get_repo(
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->has_repo(
         team_id => 1,
         repo    => 'some_repo',
     );
@@ -242,7 +300,8 @@ user must be a member of the team.
 
 Examples:
 
-    $result = $p->orgs->teams->is_member(
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->is_member(
         team_id => 1,
         user    => 'plu',
     );
@@ -259,7 +318,8 @@ List teams
 
 Examples:
 
-    $result = $p->orgs->teams->list( org => 'CPAN-API' );
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->list( org => 'CPAN-API' );
 
 =back
 
@@ -274,7 +334,8 @@ a member of the team.
 
 Examples:
 
-    $result = $p->orgs->teams->list_members( team_id => 1 );
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->list_members( team_id => 1 );
 
 =back
 
@@ -288,7 +349,8 @@ List team repos
 
 Examples:
 
-    $result = $p->orgs->teams->list_repos( team_id => 1 );
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->list_repos( team_id => 1 );
 
 =back
 
@@ -305,7 +367,8 @@ it just remove them from the team.
 
 Examples:
 
-    $result = $p->orgs->teams->remove_member(
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->remove_member(
         team_id => 1,
         user    => 'plu',
     );
@@ -323,7 +386,8 @@ an owner of the org that the team is associated with.
 
 Examples:
 
-    $result = $p->orgs->teams->remove_repo(
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->remove_repo(
         team_id => 1,
         repo    => 'some_repo',
     );
@@ -341,7 +405,8 @@ of the org that the team is associated with.
 
 Examples:
 
-    $result = $p->orgs->teams->update(
+    my $t = Pithub::Orgs::Teams->new;
+    my $result = $t->update(
         team_id => 1,
         data    => {
             name       => 'new team name',
